@@ -134,6 +134,12 @@ class PoscGlobals:
             ('$fs', self._fs if _fs is None else _fs)
         )
 
+    def clear(self):
+        """Clears the global variables."""
+        self._fn = None
+        self._fa = None
+        self._fs = None
+
 # Setting the _fn, _fs and _fa variables will result in the header to
 # the generated script to include the global parameters.
 POSC_GLOBALS = PoscGlobals()
@@ -889,6 +895,8 @@ class PoscBase(PoscRendererBase):
                 if val is None:
                     val = getattr(POSC_GLOBALS, attr)
                 args[attr] = val
+            else:
+                args[attr] = None
         return args
             
     def renderObj(self, renderer: M3dRenderer) -> RenderContext:
@@ -1218,8 +1226,8 @@ class Cylinder(PoscBase):
         centre = True if self.center else False
         return renderer.cylinder(
             self, self.h, self.get_r1(), self.get_r2(), 
-            get_fragments_from_fn_fa_fs(self.get_r1(), **self.get_fn_fa_fs_args()),
-            centre=centre)
+            fn=get_fragments_from_fn_fa_fs(self.get_r1(), **self.get_fn_fa_fs_args()),
+            center=centre)
 
 
 @apply_posc_attributes
@@ -1539,12 +1547,12 @@ class Linear_Extrude(PoscParentBase):
             FN_ARG,
         ),
         OPEN_SCAD_URL_TAIL_2D,
-        'Linear_Extrude',
     )
     
     def renderObj(self, renderer: M3dRenderer) -> RenderContext:
         return renderer.linear_extrude(self, self.height, self.center, self.convexity, 
-                                       self.twist, self.slices, self.scale_, **self.get_fn_fa_fs_args())
+                                       self.twist, self.slices, self.scale_, 
+                                       fn=self._fn if self._fn is not None else POSC_GLOBALS._fn)
 
 
 @apply_posc_transformation_attributes
